@@ -64,7 +64,7 @@ general.PODT <- function(   display_pri, Ymax=1,
         #   TODO: Needs to expand from just supporting D60 sim to allow for any observer-adapted white point.
         if( ! requireNamespace( 'spacesXYZ', quietly=TRUE ) )
             {    
-            log_string( ERROR, "Cannot adapt from ACES whitepoint to display (assumed observer adapted) whitepoint, because 'spacesXYZ' cannot be loaded." )
+            log_level( ERROR, "Cannot adapt from ACES whitepoint to display (assumed observer adapted) whitepoint, because 'spacesXYZ' cannot be loaded." )
             return( NULL )
             }
 
@@ -88,7 +88,7 @@ general.PODT <- function(   display_pri, Ymax=1,
     idx = pmatch( tolower(surround), surround.full )
     if( is.na(idx) )
         {        
-        log_string( ERROR, "surround='%s' is invalid.", surround )
+        log_level( ERROR, "surround='%s' is invalid.", surround )
         return(NULL)
         }
     surround    = surround.full[idx]        
@@ -178,7 +178,7 @@ general.PODT <- function(   display_pri, Ymax=1,
             linearCV    = darkSurround_to_dimSurround( linearCV )   # this goes to XYZ, modifies XYZ, and then back again !
 
             #   Apply desaturation to compensate for luminance difference
-            linearCV    = tcrossprod( linearCV, ODT_SAT_MAT )
+            linearCV    = tcrossprod( linearCV, p.ODT_SAT_MAT )
             }
             
             
@@ -239,7 +239,7 @@ general.PODT <- function(   display_pri, Ymax=1,
         if( surround == 'dim' )
             {
             #   Undo desaturation to compensate for luminance difference
-            linearCV    = tcrossprod( linearCV, ODT_SAT_MAT_inv )
+            linearCV    = tcrossprod( linearCV, p.ODT_SAT_MAT_inv )
 
             #   Undo gamma adjustment to compensate for dim surround
             linearCV    = dimSurround_to_darkSurround( linearCV )
